summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabbertransport.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabbertransport.h')
-rw-r--r--kopete/protocols/jabber/jabbertransport.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/jabber/jabbertransport.h b/kopete/protocols/jabber/jabbertransport.h
index e03be173..3f14fcc5 100644
--- a/kopete/protocols/jabber/jabbertransport.h
+++ b/kopete/protocols/jabber/jabbertransport.h
@@ -45,18 +45,18 @@ class JabberTransport : public Kopete::Account
public:
/**
* constructor called when the transport is created by info from server (i.e not when loading kopete)
* @param tqparentAccount is the tqparent jabber account.
* @param item is the roster item of the gateway
* @param gateway_type eg: "msn" or "icq" only used when the account is not loaded from config file for determining the icon
*/
- JabberTransport (JabberAccount * tqparentAccount, const XMPP::RosterItem &item, const TQString& gateway_type=TQString());
+ JabberTransport (JabberAccount * parentAccount, const XMPP::RosterItem &item, const TQString& gateway_type=TQString());
/**
* constructor called when the transport is loaded from config
* @param tqparentAccount is the tqparent jabber account.
* @param accountId is the accountId
*/
- JabberTransport (JabberAccount * tqparentAccount, const TQString &accountId );
+ JabberTransport (JabberAccount * parentAccount, const TQString &accountId );
~JabberTransport ();
@@ -123,12 +123,12 @@ protected:
* method should have the "dirty" flag set.
*
* This method should simply be used to intantiate the new contact, everything else
- * (updating the GUI, tqparenting to meta contact, etc.) is being taken care of.
+ * (updating the GUI, parenting to meta contact, etc.) is being taken care of.
*
* @param contactId The unique ID for this protocol
* @param tqparentContact The metacontact to add this contact to
*/
- virtual bool createContact (const TQString & contactID, Kopete::MetaContact * tqparentContact);
+ virtual bool createContact (const TQString & contactID, Kopete::MetaContact * parentContact);
private:
JabberAccount *m_account;
@@ -45,18 +45,18 @@ class JabberTransport : public Kopete::Account
/**
* constructor called when the transport is created by info from server (i.e not when loading kopete)
- * @param tqparentAccount is the tqparent jabber account.
+ * @param parentAccount is the tqparent jabber account.
* @param item is the roster item of the gateway
* @param gateway_type eg: "msn" or "icq" only used when the account is not loaded from config file for determining the icon
@@ -45,18 +45,18 @@ class JabberTransport : public Kopete::Account
/**
* constructor called when the transport is loaded from config
- * @param tqparentAccount is the tqparent jabber account.
+ * @param parentAccount is the tqparent jabber account.
* @param accountId is the accountId
*/
@@ -123,12 +123,12 @@ protected:
*
* @param contactId The unique ID for this protocol
- * @param tqparentContact The metacontact to add this contact to
+ * @param parentContact The metacontact to add this contact to
*/